ChatImageList class

图片记录集合 工具类

Constructors

ChatImageList()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

imageList → List<ChatImageListUtils>
图片记录集合
no setter
isNeedScrollBottom → bool
初始渲染时是否滑动到底部
no setter
isOpenPreviewImage → bool
当前是否开启图片预览状态
no setter

Static Methods

addImageList(ChatImageListUtils chatImageListUtils) → void
添加
clearImageList() → void
对当前图片记录集合进行操作 清空
indexWhereImageList(bool condition(ChatImageListUtils element)) → int
索引查找
modifyIsNeedScrollBottom(bool status) → void
修改 初始渲染时是否滑动到底部 状态
modyfyIsOpenPreviewImage({required bool status}) → void
修改当前可预览状态