ChatImageListUtils class

标记生成当前唯一内容

Constructors

ChatImageListUtils({required int id, required ImageProvider<Object> imageProvider})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
唯一 ID
getter/setter pair
imageProvider ↔ ImageProvider<Object>
图片内容
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited