ChatViewItemAvatarModel class

头像 model

Constructors

ChatViewItemAvatarModel({String? avatarPath, String? defaultAvatarPath, bool isAvatarShow = true, double? avatarSize, Color? avatarColor, Widget? customAvatar, Widget? customAvatarWidget, void avatarTap()?})

Properties

avatarColor → Color?
头像颜色
final
avatarPath → String?
头像地址
final
avatarSize → double?
头像大小
final
avatarTap → void Function()?
头像点击回调
final
customAvatar → Widget?
自定义头像
final
customAvatarWidget → Widget?
自定义头像盒子
final
defaultAvatarPath → String?
默认头像地址
final
hashCode → int
The hash code for this object.
no setterinherited
isAvatarShow → bool
是否展示头像
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited