CustomSelectionArea class

自定义的选择文字组件

Inheritance

Constructors

CustomSelectionArea({Key? key, required Text child, bool isOpen = true, TextStyle? itemBodyTextStyle, TextSelectionControls? selectionControls, void onSelectionChanged(TextSelection selection, SelectionChangedCause? cause)?, Widget contextMenuBuilder(BuildContext context, EditableTextState editableTextState)?, void createSelectableTextCallback(FocusNode focusNode)?, TextMagnifierConfiguration? magnifierConfiguration})
const

Properties

child → Text
子组件
final
contextMenuBuilder → Widget Function(BuildContext context, EditableTextState editableTextState)?
显示的工具菜单
final
createSelectableTextCallback → void Function(FocusNode focusNode)?
SelectableText 创建时
final
hashCode → int
The hash code for this object.
no setterinherited
isOpen → bool
是否开启
final
itemBodyTextStyle → TextStyle?
文字样式
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
magnifierConfiguration → TextMagnifierConfiguration?
文本放大镜配置
final
onSelectionChanged → void Function(TextSelection selection, SelectionChangedCause? cause)?
长按文字菜单选择回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionControls → TextSelectionControls?
文本选择控制器
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomSelectionArea>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited