ImageBox class

图片盒子

Inheritance

Constructors

ImageBox({Key? key, required String imagePath, required ChatViewItemImageTypeModel imageTypeModel, required bool isImageLoad, ImageProvider<Object>? imageProviderInfo, Image? imageInfo, ChatImageListUtils? chatImageListUtils})
const

Properties

chatImageListUtils → ChatImageListUtils?
预览图片需要的内容
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
图片高度
no setter
imageInfo → Image?
获取到的图片信息
final
imagePath → String
图片路径
final
imageProviderInfo → ImageProvider<Object>?
图片内容
final
imageTypeModel → ChatViewItemImageTypeModel
图片类型配置内容
final
isImageLoad → bool
图片可加载状态
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight → double
图片最大展示高度
no setter
maxWidth → double
图片最大展示宽度
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
图片宽度
no setter

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited